| Copyright | Will Thompson Iñaki García Etxebarria and Jonas Platte |
|---|---|
| License | LGPL-2.1 |
| Maintainer | Iñaki García Etxebarria |
| Safe Haskell | None |
| Language | Haskell2010 |
GI.GstTag.Interfaces.TagXmpWriter
Description
This interface is implemented by elements that are able to do XMP serialization. Examples for
such elements are jifmux and qtmux.
Applications can use this interface to configure which XMP schemas should be used when serializing
tags into XMP. Schemas are represented by their names, a full list of the supported schemas can be
obtained from tagXmpListSchemas. By default, all schemas are used.
Synopsis
- newtype TagXmpWriter = TagXmpWriter (ManagedPtr TagXmpWriter)
- noTagXmpWriter :: Maybe TagXmpWriter
- class (GObject o, IsDescendantOf TagXmpWriter o) => IsTagXmpWriter o
- toTagXmpWriter :: (MonadIO m, IsTagXmpWriter o) => o -> m TagXmpWriter
- tagXmpWriterAddAllSchemas :: (HasCallStack, MonadIO m, IsTagXmpWriter a) => a -> m ()
- tagXmpWriterAddSchema :: (HasCallStack, MonadIO m, IsTagXmpWriter a) => a -> Text -> m ()
- tagXmpWriterHasSchema :: (HasCallStack, MonadIO m, IsTagXmpWriter a) => a -> Text -> m Bool
- tagXmpWriterRemoveAllSchemas :: (HasCallStack, MonadIO m, IsTagXmpWriter a) => a -> m ()
- tagXmpWriterRemoveSchema :: (HasCallStack, MonadIO m, IsTagXmpWriter a) => a -> Text -> m ()
- tagXmpWriterTagListToXmpBuffer :: (HasCallStack, MonadIO m, IsTagXmpWriter a) => a -> TagList -> Bool -> m Buffer
Exported types
newtype TagXmpWriter Source #
Memory-managed wrapper type.
Constructors
| TagXmpWriter (ManagedPtr TagXmpWriter) |
Instances
| Eq TagXmpWriter Source # | |
Defined in GI.GstTag.Interfaces.TagXmpWriter | |
| GObject TagXmpWriter Source # | |
Defined in GI.GstTag.Interfaces.TagXmpWriter Methods gobjectType :: IO GType # | |
| IsGValue TagXmpWriter Source # | Convert |
Defined in GI.GstTag.Interfaces.TagXmpWriter | |
| HasParentTypes TagXmpWriter Source # | |
Defined in GI.GstTag.Interfaces.TagXmpWriter | |
| type ParentTypes TagXmpWriter Source # | |
Defined in GI.GstTag.Interfaces.TagXmpWriter | |
noTagXmpWriter :: Maybe TagXmpWriter Source #
A convenience alias for Nothing :: Maybe TagXmpWriter.
class (GObject o, IsDescendantOf TagXmpWriter o) => IsTagXmpWriter o Source #
Type class for types which can be safely cast to TagXmpWriter, for instance with toTagXmpWriter.
Instances
| (GObject o, IsDescendantOf TagXmpWriter o) => IsTagXmpWriter o Source # | |
Defined in GI.GstTag.Interfaces.TagXmpWriter | |
toTagXmpWriter :: (MonadIO m, IsTagXmpWriter o) => o -> m TagXmpWriter Source #
Cast to TagXmpWriter, for types for which this is known to be safe. For general casts, use castTo.
Methods
Overloaded methods
addAllSchemas
tagXmpWriterAddAllSchemas Source #
Arguments
| :: (HasCallStack, MonadIO m, IsTagXmpWriter a) | |
| => a |
|
| -> m () |
Adds all available XMP schemas to the configuration. Meaning that all will be used.
addSchema
tagXmpWriterAddSchema Source #
Arguments
| :: (HasCallStack, MonadIO m, IsTagXmpWriter a) | |
| => a |
|
| -> Text |
|
| -> m () |
Adds schema to the list schemas
hasSchema
tagXmpWriterHasSchema Source #
Arguments
| :: (HasCallStack, MonadIO m, IsTagXmpWriter a) | |
| => a |
|
| -> Text |
|
| -> m Bool | Returns: |
Checks if schema is going to be used
removeAllSchemas
tagXmpWriterRemoveAllSchemas Source #
Arguments
| :: (HasCallStack, MonadIO m, IsTagXmpWriter a) | |
| => a |
|
| -> m () |
Removes all schemas from the list of schemas to use. Meaning that no XMP will be generated.
removeSchema
tagXmpWriterRemoveSchema Source #
Arguments
| :: (HasCallStack, MonadIO m, IsTagXmpWriter a) | |
| => a |
|
| -> Text |
|
| -> m () |
Removes a schema from the list of schemas to use. Nothing is done if the schema wasn't in the list
tagListToXmpBuffer
tagXmpWriterTagListToXmpBuffer :: (HasCallStack, MonadIO m, IsTagXmpWriter a) => a -> TagList -> Bool -> m Buffer Source #
No description available in the introspection data.